Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7907)

Unified Diff: base/process/process_metrics.h

Issue 2838803003: Add a field platform_private_footprint_ to ProcessMemoryTotals. (Closed)
Patch Set: Comments from mark. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | base/process/process_metrics_mac.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/process/process_metrics.h
diff --git a/base/process/process_metrics.h b/base/process/process_metrics.h
index 6e5e796a7c825be5d390d0b79fdd9ac373d45ae0..06d4ba915a56f822f0db23febfc41d0b77b6cc8d 100644
--- a/base/process/process_metrics.h
+++ b/base/process/process_metrics.h
@@ -167,10 +167,20 @@ class BASE_EXPORT ProcessMetrics {
bool GetCommittedAndWorkingSetKBytes(CommittedKBytes* usage,
WorkingSetKBytes* ws_usage) const;
- // Returns the physical footprint, only available on macOS 10.11+. This
- // measures anonymous, non-discardable memory. Returns 0 on error, or if the
- // measurement was unavailable.
- size_t GetPhysicalFootprint() const;
+ struct TaskVMInfo {
+ // Only available on macOS 10.12+.
+ // Anonymous, non-discardable memory, including non-volatile IOKit.
+ // Measured in bytes.
+ uint64_t phys_footprint = 0;
+
+ // Anonymous, non-discardable, non-compressed memory, excluding IOKit.
+ // Measured in bytes.
+ uint64_t internal = 0;
+
+ // Compressed memory measured in bytes.
+ uint64_t compressed = 0;
+ };
+ TaskVMInfo GetTaskVMInfo() const;
// Returns private, shared, and total resident bytes. |locked_bytes| refers to
// bytes that must stay resident. |locked_bytes| only counts bytes locked by
« no previous file with comments | « no previous file | base/process/process_metrics_mac.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698